@@ -29,11 +29,16 @@
 #define UKWS_OBJ_WINBOX             "winbox"
 #define UKWS_OBJ_WINBOX_WIN_NAME    "winbox-wintitle"
 #define UKWS_OBJ_WINBOX_THUMBNAIL   "winbox-thumbnail"
+#define UKWS_OBJ_WINBOX_CLOSEBTN    "winbox-closebtn"
 #define UKWS_OBJ_WSBOX              "wsbox"
 #define UKWS_OBJ_WSBOX_THUMBNAIL    "wsbox-thumbnail"
 #define UKWS_OBJ_NEW_WS_TITLE       "new-workspace-title"
 #define UKWS_OBJ_NEW_WS_LABEL       "new-workspace-label"
 
+#define UKWS_DBUS_NAME_PREFIX       "org.ukui.WindowSwitch.Display"
+#define UKWS_DBUS_PATH              "/org/ukui/WindowSwitch"
+#define UKWS_DBUS_INTERFACE         "org.ukui.WindowSwitch"
+
 enum UkwsWidgetShowStatus {
     Hidden = 0,
     Shown,
