@@ -33,12 +33,11 @@
 #include <QScrollBar>
 #include <QTime>
 #include <QCursor>
+#include <QAction>
 
-extern "C" {
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <unistd.h>
-}
 
 UkwsIndicator::UkwsIndicator(QWidget *parent) : QWidget(parent)
 {
@@ -54,6 +53,8 @@ UkwsIndicator::UkwsIndicator(QWidget *parent) : QWidget(parent)
     config = nullptr;
 
     wmOperator = new UkwsWnckOperator;
+    wlHandler = new UkwsWaylandHandler;
+
     flowScrollArea = new QScrollArea();
     flowArea = new QWidget();
     winboxFlowLayout = new UkwsFlowLayout(flowArea, 0, 8, 8);
@@ -76,6 +77,7 @@ UkwsIndicator::UkwsIndicator(QWidget *parent) : QWidget(parent)
     mainLayout->setAlignment(Qt::AlignCenter);
     mainLayout->setMargin(0);
     this->setLayout(mainLayout);
+    //this->setBackgroundRole();
 
     // 设置悬浮滚动条
     flowScrollBar = new QScrollBar(Qt::Vertical, this);
@@ -95,6 +97,10 @@ UkwsIndicator::UkwsIndicator(QWidget *parent) : QWidget(parent)
     flowScrollBar->setObjectName(UKWS_OBJ_FLOW_SCROLLBAR);
     this->setObjectName(UKWS_OBJ_IND_MAINWIDGET_SWITCH);
 
+    windowListcheckTimer.setTimerType(Qt::CoarseTimer);
+    windowListcheckTimer.setInterval(UKWS_WINDOW_LIST_CHECK_INTERVAL_MS);
+    connect(&(this->windowListcheckTimer), &QTimer::timeout, this, &UkwsIndicator::checkWindowList);
+
     this->installEventFilter(this);
 }
 
@@ -182,6 +188,17 @@ void UkwsIndicator::setConfig(UkwsConfig *config)
     this->config = config;
 }
 
+void UkwsIndicator::checkWindowList()
+{
+    foreach (UkwsWindowBox * winbox, winboxList) {
+        if (winbox->windowIsAlive())
+            continue;
+
+        // 非窗口，则代表窗口被关闭，需要从列表和layout中移除，并释放资源
+        rmWinbox(winbox);
+    }
+}
+
 void UkwsIndicator::addWinbox(UkwsWindowBox *winbox)
 {
     // 添加到列表最后，所以index = size()
@@ -190,13 +207,16 @@ void UkwsIndicator::addWinbox(UkwsWindowBox *winbox)
     winboxList.append(winbox);
     winboxFlowLayout->addWidget(winbox);
     connect(winbox, &UkwsWindowBox::clicked, this, &UkwsIndicator::clickWinbox);
+    connect(winbox, &UkwsWindowBox::closeBtnClicked, this, &UkwsIndicator::closeWinbox);
 }
 
 void UkwsIndicator::rmWinbox(UkwsWindowBox *winbox)
 {
+    winbox->hide();
     winboxFlowLayout->removeWidget(winbox);
     winboxList.removeOne(winbox);
     disconnect(winbox, &UkwsWindowBox::clicked, this, &UkwsIndicator::clickWinbox);
+    disconnect(winbox, &UkwsWindowBox::closeBtnClicked, this, &UkwsIndicator::closeWinbox);
 
     // 更新索引
     int size = winboxList.size();
@@ -205,6 +225,60 @@ void UkwsIndicator::rmWinbox(UkwsWindowBox *winbox)
         wb = winboxList.at(i);
         wb->index = i;
     }
+
+    flowReLayout();
+} 
+
+void UkwsIndicator::setWaylandWindowHide(quint32 wl_winId, int state)
+{
+    for(int i = 0; i < winboxList.size(); i++)
+    {
+        if(wl_winId == winboxList.at(i)->wl_windowId)
+        {if(state == 3){
+                QDBusMessage message = QDBusMessage::createSignal("/", "com.ukui.kwin", "request");
+                QList<QVariant> args;
+                quint32 m_wid=wl_winId;
+                args.append(m_wid);
+                args.append(0);
+                message.setArguments(args);
+                QDBusConnection::sessionBus().send(message);
+            }
+            else
+            {
+                        
+            }
+        }
+    }
+}
+
+void UkwsIndicator::setWaylandWindowShow(quint32 wl_winId, int state)
+{
+    for(int i = 0; i < winboxList.size(); i++)
+    {
+        if(wl_winId == winboxList.at(i)->wl_windowId)
+        {
+            if(state == 1){
+                QDBusMessage message = QDBusMessage::createSignal("/", "com.ukui.kwin", "request");
+                QList<QVariant> args;
+                quint32 m_wid=wl_winId;
+                args.append(m_wid);
+                args.append(1);
+                message.setArguments(args);
+                QDBusConnection::sessionBus().send(message);
+            }
+            else
+            {
+                QDBusMessage message = QDBusMessage::createSignal("/", "com.ukui.kwin", "request");
+                QList<QVariant> args;
+                quint32 m_wid=wl_winId;
+                args.append(m_wid);
+                args.append(0);
+                message.setArguments(args);
+                QDBusConnection::sessionBus().send(message);
+            }
+
+        }
+    }
 }
 
 void UkwsIndicator::cleanAllWinbox()
@@ -279,7 +353,9 @@ void UkwsIndicator::reloadWindowList(int boxMinHeight)
         cleanAllWinbox();
 
     wmOperator->updateWindowList();
-    int size = wmOperator->windowQList->size();
+
+    int wnckSize = wmOperator->windowQList->size();
+    int waylandSize = wlHandler->wl_winIdList.size();
 
     // 获取屏幕大小
     QDesktopWidget *desktop = QApplication::desktop();
@@ -297,10 +373,11 @@ void UkwsIndicator::reloadWindowList(int boxMinHeight)
     QSize dragIconSize = QSize(w * 0.8, h * 0.8);
 
 
-    for (int i = 0; i < size; i++) {
+    for (int i = 0; i < wnckSize; i++) {
         WnckWindow *win = wmOperator->windowQList->at(i);
         UkwsWindowBox *wb = new UkwsWindowBox;
 
+        wb->winBaseType = 0;
         wb->setWnckWindow(win);
 
         // 设置Winbox大小
@@ -319,6 +396,45 @@ void UkwsIndicator::reloadWindowList(int boxMinHeight)
 
         addWinbox(wb);
     }
+
+    for(int i = 0; i < waylandSize; i++)
+    {
+        quint32 nWayWin = wlHandler->wl_winIdList.at(i);
+        qDebug() << "add wayland box: " << wlHandler->wl_winIdList.at(i);
+        UkwsWindowBox *wb = new UkwsWindowBox;
+
+        wb->winBaseType = 1;
+
+        wb->setWaylandWindow(nWayWin);
+        wb->setOrigThumbnailOfWayland();
+        wb->setWinboxSizeByHeight(boxMinHeight);
+        wb->setDragIconSize(dragIconSize);
+
+        //wb->setIcon(nullptr);
+        wb->setTitle("kylin-video");
+
+        if (showMode == UkwsIndicatorShowMode::ShowModeTiling) {
+            wb->dragable = true;
+            wb->setTitleAutoHide(true);
+        }
+        addWinbox(wb);
+    }
+}
+
+void UkwsIndicator::removeWaylandWindow(quint32 wl_winId)
+{
+    UkwsWindowBox *wb = new UkwsWindowBox;
+    wlHandler->removeWaylandWindow(wl_winId);
+    wb->setWaylandWindow(wl_winId);
+    wb->closeWaylandWindow();
+}
+
+void UkwsIndicator::getWaylandWinInfo(quint32 wl_winId, QString wl_iconName, QString wl_caption)
+{
+
+    wlHandler->addWaylandWindow(wl_winId);
+    wlHandler->setWaylandWindowIconName(wl_iconName);
+    wlHandler->setWaylandWindowTitle(wl_caption);
 }
 
 void UkwsIndicator::reSetWindowThumbnailByWnck()
@@ -360,8 +476,13 @@ void UkwsIndicator::reSetWindowThumbnailByWnck()
     // 开始处理
     for (i = 0; i < cpus; i++) {
         workerList.at(i)->doingThread->start();
+    }   
+
+    for (i = 0; i < cpus; i++) {
+        workerList.at(i)->doingThread->wait();
     }
 
+
     // 不等待缩略图完全生成，直接进行之后的步骤
 }
 
@@ -402,8 +523,14 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
         }
     } else {
         // 多任务视图展现在主屏上
-        QDesktopWidget *desktop = QApplication::desktop();
-        screenIndex = desktop->primaryScreen();
+        for(int i = 0; i < screenCount; i++){
+            QScreen *priScreen = QGuiApplication::screens().at(i);
+            if(priScreen == QGuiApplication::primaryScreen())
+                screenIndex = i;
+        }
+        //QDesktopWidget *desktop = QApplication::desktop();
+        //QDesktopWidget *des = QGuiApplication::primaryScreen();
+        //screenIndex = desktop->primaryScreen();
     }
 
 //    screenRect =  desktop->availableGeometry(screenIndex);
@@ -444,7 +571,6 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
 //        this->reSetWindowThumbnailByWnck();
         return;
     }
-
     for (int i = (minScale * 2 - 1); i > 4; i--) {
         scale = i / 2.0;
         winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / scale)
@@ -530,7 +656,11 @@ void UkwsIndicator::reHide(bool needActivate)
 
     if (needActivate) {
         UkwsWindowBox *wb = winboxList.at(selIndex);
-        wb->activateWnckWindow();
+        if(wb->winBaseType == 0)
+            wb->activateWnckWindow();
+        if(wb->winBaseType == 1)
+            wb->activateWaylandWindow();
+
         selIndex = -1;
     }
 
@@ -571,7 +701,12 @@ void UkwsIndicator::acitveSelectedWindow()
         return;
 
     UkwsWindowBox *wb = winboxList.at(selIndex);
-    wb->activateWnckWindow();
+    if(wb->winBaseType == 0)
+        wb->activateWnckWindow();
+    else if(wb->winBaseType == 1)
+        wb->activateWaylandWindow();
+    else
+        return;
 }
 
 bool UkwsIndicator::updateWindowViewPixmap(bool newRequest)
@@ -636,6 +771,24 @@ void UkwsIndicator::clickWinbox(UkwsWindowBox *wb)
     emit isSelected(true);
 }
 
+void UkwsIndicator::closeWinbox(UkwsWindowBox *wb)
+{
+    selIndex = winboxList.indexOf(wb);
+//    qDebug() << "indicator: winbox" << selIndex << "will close";
+    if(wb->winBaseType == 0)
+    {
+        wb->closeWnckWindow();
+        emit closeWindowRefresh(this->index);
+    }
+    else if(wb->winBaseType == 1)
+    {
+        wb->closeWaylandWindow();
+        emit closeWindowRefresh(this->index);
+    }
+    else
+        return;
+}
+
 void UkwsIndicator::flowReLayout()
 {
     // 获取可视区域尺寸
